@@ -31,9 +31,9 @@
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 #include <libxml/HTMLparser.h>
-#include <config.h>
 
-#include <glib/gi18n.h>
+#include <config.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
 #include <gtk/gtk.h>
@@ -632,7 +632,7 @@ check_mime_type(const gchar* uri,GError** error)
         const gchar* mimetypes[] = {"application/epub+zip", "application/x-booki+zip", NULL};
         guint i;
 
-        for (i = 0; i < g_strv_length (mimetypes); i++) {
+        for (i = 0; mimetypes[i]; i++) {
            if (strcmp(mimeFromFile, mimetypes[i]) == 0)
                 return TRUE;
         }
@@ -643,7 +643,7 @@ check_mime_type(const gchar* uri,GError** error)
             mimeFromFile = ev_file_get_mime_type (uri, TRUE, &err);
             if (mimeFromFile)
             {
-                for (i = 0; i < g_strv_length (mimetypes); i++) {
+                for (i = 0; i < G_N_ELEMENTS (mimetypes); i++) {
                     if (g_strcmp0(mimeFromFile, mimetypes[i]) == 0)
                         return TRUE;
                 }
@@ -1044,7 +1044,7 @@ setup_document_content_list(const gchar* content_uri, GError** error,gchar *docu
         }
         if ( xmlStrcmp(itemrefptr->name,(xmlChar*)"itemref") == 0)
         {
-            contentListNode *newnode = g_malloc0(sizeof(newnode));
+            contentListNode *newnode = g_malloc0(sizeof(*newnode));
             newnode->key = (gchar*)xml_get_data_from_node(itemrefptr,XML_ATTRIBUTE,(xmlChar*)"idref");
             if ( newnode->key == NULL )
             {
@@ -1626,7 +1626,7 @@ page_set_function(linknode *Link, GList *contentList)
     contentListNode *pagedata;
 
     guint flag=0;
-    while (!flag) {
+    while (!flag && listiter) {
         pagedata = listiter->data;
         if (link_present_on_page(Link->pagelink, pagedata->value)) {
             flag=1;
